; test TIM8T as a loop counter
; Written by Omegamatrix


      processor 6502

VSYNC   =  $00
VBLANK  =  $01
WSYNC   =  $02
NUSIZ0  =  $04
NUSIZ1  =  $05
COLUP0  =  $06
COLUP1  =  $07
COLUBK  =  $09
CTRLPF  =  $0A
RESP0   =  $10
RESP1   =  $11
GRP0    =  $1B
GRP1    =  $1C
HMP0    =  $20
HMP1    =  $21
VDELP0  =  $25
VDELP1  =  $26
HMOVE   =  $2A
INTIM   =  $0284
TIM8T   =  $0295
TIM64T  =  $0296


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;      USER CONSTANTS
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

TIME_OVERSCAN  = 27
TIME_VBLANK    = $31

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;      RAM
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

       SEG.U Variables
       ORG $80


digits           ds 6
topGfxPtrs       ds 12
botGfxPtrs       ds 12
frameCounter     ds 1
loopCount        ds 1
tempGfx          ds 1

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;      MAIN PROGRAM
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

       SEG Code
       ORG $F000

START:
    cld
    ldx    #0
    txa
.loopClear:
    dex
    txs
    pha
    bne    .loopClear


;one time initializations...
    sta   WSYNC
;---------------------------------------
    sta    CTRLPF                ;3  @3
    lda    #$0F                  ;2  @5     white
    sta    COLUP0                ;3  @8
    sta    COLUP1                ;3  @11
    sta    VDELP0                ;3  @14    delay
    sta    VDELP1                ;3  @17
    lda    #$03                  ;2  @19
    sta    NUSIZ0                ;3  @22    3 copies close
    sta    NUSIZ1                ;3  @25
    lda    #$B0                  ;2  @27    right 5
    sta    HMP0                  ;3  @30
    lda    #$C0                  ;2  @32    right 4
    sta    HMP1                  ;3  @35
    sta    RESP0                 ;3  @38
    sta    RESP1                 ;3  @41

    sta    WSYNC                 ;3  @76
;---------------------------------------
    sta    HMOVE

    lda    #$C6
    sta    COLUBK

    lda    #0
    sta    digits
    lda    #1
    sta    digits+1
    lda    #2
    sta    digits+2
    lda    #3
    sta    digits+3
    lda    #4
    sta    digits+4
    lda    #5
    sta    digits+5



    lda    #>Zero
    sta    topGfxPtrs+1
    sta    topGfxPtrs+3
    sta    topGfxPtrs+5
    sta    topGfxPtrs+7
    sta    topGfxPtrs+9
    sta    topGfxPtrs+11

    lda    #>LineOneGfx_A
    sta    botGfxPtrs+1
    sta    botGfxPtrs+3
    sta    botGfxPtrs+5
    sta    botGfxPtrs+7
    sta    botGfxPtrs+9
    sta    botGfxPtrs+11


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; Vsync
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

MainLoop:
    lda    #$0E
.loopVsync:
    sta    WSYNC
;---------------------------------------
    sta    VSYNC
    lsr
    bne    .loopVsync
    lda    #TIME_VBLANK
    sta    TIM64T

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; scroll digits left
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
    lda    frameCounter
    and    #$07
    bne    .skipScroll
    ldy    #5

.updateDigits:
    ldx    digits,Y
    inx
    cpx    #18
    bcc    .digitUpdate
    ldx    #0
.digitUpdate:
    stx    digits,Y
    dey
    bpl    .updateDigits

.skipScroll:


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; load all low pointers
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

    ldy    digits+5
    lda    StandardNumTab,Y
    sta    topGfxPtrs+10
    lda    FasterNumTab,Y
    sta    botGfxPtrs+10

    ldy    digits+4
    lda    StandardNumTab,Y
    sta    topGfxPtrs+8
    lda    FasterNumTab,Y
    sta    botGfxPtrs+8

    ldy    digits+3
    lda    StandardNumTab,Y
    sta    topGfxPtrs+6
    lda    FasterNumTab,Y
    sta    botGfxPtrs+6

    ldy    digits+2
    lda    StandardNumTab,Y
    sta    topGfxPtrs+4
    lda    FasterNumTab,Y
    sta    botGfxPtrs+4

    ldy    digits+1
    lda    StandardNumTab,Y
    sta    topGfxPtrs+2
    lda    FasterNumTab,Y
    sta    botGfxPtrs+2

    ldy    digits
    lda    StandardNumTab,Y
    sta    topGfxPtrs
    lda    FasterNumTab,Y
    sta    botGfxPtrs




;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; finish Vblank
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

.waitVblank:
    lda    INTIM
    bne    .waitVblank
    sta    WSYNC
;---------------------------------------
    sta    VBLANK


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; top lines
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

    ldy    #83
.loopTop:
    sta    WSYNC
;---------------------------------------
    dey
    bne    .loopTop


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; standard 48 bit display
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

    ldy    #7
    sty    loopCount
.loopStandard48bit:
    lda    (topGfxPtrs+10),Y     ;5  @69
    sta    tempGfx               ;3  @72
    sta    WSYNC                 ;3
;---------------------------------------
    lda    (topGfxPtrs),Y        ;5  @5
    sta    GRP0                  ;3  @8
    lda    (topGfxPtrs+2),Y      ;5  @13
    sta    GRP1                  ;3  @16
    lda    (topGfxPtrs+4),Y      ;5  @21
    sta    GRP0                  ;3  @24
    lax    (topGfxPtrs+8),Y      ;5  @29
    lda    (topGfxPtrs+6),Y      ;5  @34
    ldy    tempGfx               ;3  @37
    nop                          ;2  @39     8 free cycles in loop
    nop                          ;2  @41
    sta    GRP1                  ;3  @44
    stx    GRP0                  ;3  @47
    sty    GRP1                  ;3  @50
    sta    GRP0                  ;3  @53
    dec    loopCount             ;5  @58
    ldy    loopCount             ;3  @61
    bpl    .loopStandard48bit    ;2 @63/64


    iny
    sty    GRP0
    sty    GRP1
    sty    GRP0
    sty    GRP1

    sta    WSYNC
    sta    WSYNC
    sta    WSYNC
;---------------------------------------
    dec    $2E                   ;5  @5
    dec    $2E                   ;5  @10
    dec    $2E                   ;5  @15
    dec    $2E                   ;5  @20
    dec    $2E                   ;5  @25
    dec    $2E                   ;5  @30
    dec    $2E                   ;5  @35
    dec    $2E                   ;5  @40
    dec    $2E                   ;5  @45
    nop                          ;2  @47
    nop                          ;2  @49
    nop                          ;2  @51
    ldy    #<LineOneGfx_A        ;2  @53
    sty    TIM8T                 ;4  @57



.loopFaster48bit:
    lda    (botGfxPtrs+10),Y     ;5  @65
    sta    tempGfx               ;3  @68
    sta    WSYNC                 ;3
;---------------------------------------
    lda    (botGfxPtrs),Y        ;5  @5
    sta    GRP0                  ;3  @8
    lda    (botGfxPtrs+2),Y      ;5  @13
    sta    GRP1                  ;3  @16
    lda    (botGfxPtrs+4),Y      ;5  @21
    sta    GRP0                  ;3  @24
    lax    (botGfxPtrs+8),Y      ;5  @29
    lda    (botGfxPtrs+6),Y      ;5  @34
    ldy    tempGfx               ;3  @37
    nop                          ;2  @39   12 free cycles in loop, 1 zero page ram saved...
    nop                          ;2  @41
    sta    GRP1                  ;3  @44
    stx    GRP0                  ;3  @47
    sty    GRP1                  ;3  @50
    sta    GRP0                  ;3  @53
    ldy    INTIM                 ;4  @57
    bpl    .loopFaster48bit      ;2 @59/60

    lda    #0
    sta    GRP0
    sta    GRP1
    sta    GRP0
    sta    GRP1

    ldy    #92
.loopBottom:
    sta    WSYNC
;---------------------------------------
    dey
    bne    .loopBottom

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;      OVERSCAN
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

    lda    #$82
    sta    WSYNC
;---------------------------------------
    sta    VBLANK
    lda    #TIME_OVERSCAN
    sta    TIM64T

    inc    frameCounter

.waitOverscan:
    lda    INTIM
    bne    .waitOverscan
    jmp    MainLoop


       ORG $FE00

LineEightGfx_A:
    .byte Line8_Zero
    .byte Line8_One
    .byte Line8_Two
    .byte Line8_Three
    .byte Line8_Four
    .byte Line8_Five
    .byte Line8_Six
    .byte Line8_Seven
    .byte Line8_Eight
    .byte 0  ; free byte
LineSevenGfx_A:
    .byte Line7_Zero
    .byte Line7_One
    .byte Line7_Two
    .byte Line7_Three
    .byte Line7_Four
    .byte Line7_Five
    .byte Line7_Six
    .byte Line7_Seven
    .byte Line7_Eight
LineSixGfx_A:
    .byte Line6_Zero
    .byte Line6_One
    .byte Line6_Two
    .byte Line6_Three
    .byte Line6_Four
    .byte Line6_Five
    .byte Line6_Six
    .byte Line6_Seven
    .byte Line6_Eight
    .byte 0  ; free byte
LineFiveGfx_A:
    .byte Line5_Zero
    .byte Line5_One
    .byte Line5_Two
    .byte Line5_Three
    .byte Line5_Four
    .byte Line5_Five
    .byte Line5_Six
    .byte Line5_Seven
    .byte Line5_Eight
LineFourGfx_A:
    .byte Line4_Zero
    .byte Line4_One
    .byte Line4_Two
    .byte Line4_Three
    .byte Line4_Four
    .byte Line4_Five
    .byte Line4_Six
    .byte Line4_Seven
    .byte Line4_Eight
    .byte 0  ; free byte
LineThreeGfx_A:
    .byte Line3_Zero
    .byte Line3_One
    .byte Line3_Two
    .byte Line3_Three
    .byte Line3_Four
    .byte Line3_Five
    .byte Line3_Six
    .byte Line3_Seven
    .byte Line3_Eight
LineTwoGfx_A:
    .byte Line2_Zero
    .byte Line2_One
    .byte Line2_Two
    .byte Line2_Three
    .byte Line2_Four
    .byte Line2_Five
    .byte Line2_Six
    .byte Line2_Seven
    .byte Line2_Eight
    .byte 0  ; free byte
LineOneGfx_A:
    .byte Line1_Zero
    .byte Line1_One
    .byte Line1_Two
    .byte Line1_Three
    .byte Line1_Four
    .byte Line1_Five
    .byte Line1_Six
    .byte Line1_Seven
    .byte Line1_Eight


LineEightGfx_B:
    .byte Line8_Nine
    .byte Line8_Let_A
    .byte Line8_Let_B
    .byte Line8_Let_C
    .byte Line8_Let_D
    .byte Line8_Let_E
    .byte Line8_Let_F
    .byte Line8_Let_G
    .byte Line8_Let_H
    .byte 0  ; free byte
LineSevenGfx_B:
    .byte Line7_Nine
    .byte Line7_Let_A
    .byte Line7_Let_B
    .byte Line7_Let_C
    .byte Line7_Let_D
    .byte Line7_Let_E
    .byte Line7_Let_F
    .byte Line7_Let_G
    .byte Line7_Let_H
LineSixGfx_B:
    .byte Line6_Nine
    .byte Line6_Let_A
    .byte Line6_Let_B
    .byte Line6_Let_C
    .byte Line6_Let_D
    .byte Line6_Let_E
    .byte Line6_Let_F
    .byte Line6_Let_G
    .byte Line6_Let_H
    .byte 0  ; free byte
LineFiveGfx_B:
    .byte Line5_Nine
    .byte Line5_Let_A
    .byte Line5_Let_B
    .byte Line5_Let_C
    .byte Line5_Let_D
    .byte Line5_Let_E
    .byte Line5_Let_F
    .byte Line5_Let_G
    .byte Line5_Let_H
LineFourGfx_B:
    .byte Line4_Nine
    .byte Line4_Let_A
    .byte Line4_Let_B
    .byte Line4_Let_C
    .byte Line4_Let_D
    .byte Line4_Let_E
    .byte Line4_Let_F
    .byte Line4_Let_G
    .byte Line4_Let_H
     .byte 0  ; free byte
LineThreeGfx_B:
    .byte Line3_Nine
    .byte Line3_Let_A
    .byte Line3_Let_B
    .byte Line3_Let_C
    .byte Line3_Let_D
    .byte Line3_Let_E
    .byte Line3_Let_F
    .byte Line3_Let_G
    .byte Line3_Let_H
LineTwoGfx_B:
    .byte Line2_Nine
    .byte Line2_Let_A
    .byte Line2_Let_B
    .byte Line2_Let_C
    .byte Line2_Let_D
    .byte Line2_Let_E
    .byte Line2_Let_F
    .byte Line2_Let_G
    .byte Line2_Let_H
    .byte 0  ; free byte
LineOneGfx_B:
    .byte Line1_Nine
    .byte Line1_Let_A
    .byte Line1_Let_B
    .byte Line1_Let_C
    .byte Line1_Let_D
    .byte Line1_Let_E
    .byte Line1_Let_F
    .byte Line1_Let_G
    .byte Line1_Let_H


Line8_Zero    =  $3C ; |  XXXX  |
Line7_Zero    =  $66 ; | XX  XX |
Line6_Zero    =  $66 ; | XX  XX |
Line5_Zero    =  $76 ; | XXX XX |
Line4_Zero    =  $6E ; | XX XXX |
Line3_Zero    =  $66 ; | XX  XX |
Line2_Zero    =  $66 ; | XX  XX |
Line1_Zero    =  $3C ; |  XXXX  |

Line8_One     =  $7E ; | XXXXXX |
Line7_One     =  $18 ; |   XX   |
Line6_One     =  $18 ; |   XX   |
Line5_One     =  $18 ; |   XX   |
Line4_One     =  $18 ; |   XX   |
Line3_One     =  $18 ; |   XX   |
Line2_One     =  $38 ; |  XXX   |
Line1_One     =  $08 ; |    X   |

Line8_Two     =  $7E ; | XXXXXX |
Line7_Two     =  $60 ; | XX     |
Line6_Two     =  $60 ; | XX     |
Line5_Two     =  $3C ; |  XXXX  |
Line4_Two     =  $06 ; |     XX |
Line3_Two     =  $06 ; |     XX |
Line2_Two     =  $46 ; | X   XX |
Line1_Two     =  $3C ; |  XXXX  |

Line8_Three   =  $3C ; |  XXXX  |
Line7_Three   =  $46 ; | X   XX |
Line6_Three   =  $06 ; |     XX |
Line5_Three   =  $0C ; |    XX  |
Line4_Three   =  $0C ; |    XX  |
Line3_Three   =  $06 ; |     XX |
Line2_Three   =  $46 ; | X   XX |
Line1_Three   =  $3C ; |  XXXX  |

Line8_Four    =  $0C ; |    XX  |
Line7_Four    =  $0C ; |    XX  |
Line6_Four    =  $0C ; |    XX  |
Line5_Four    =  $7E ; | XXXXXX |
Line4_Four    =  $4C ; | X  XX  |
Line3_Four    =  $2C ; |  X XX  |
Line2_Four    =  $1C ; |   XXX  |
Line1_Four    =  $0C ; |    XX  |

Line8_Five    =  $3C ; |  XXXX  |
Line7_Five    =  $46 ; | X   XX |
Line6_Five    =  $06 ; |     XX |
Line5_Five    =  $06 ; |     XX |
Line4_Five    =  $7C ; | XXXXX  |
Line3_Five    =  $60 ; | XX     |
Line2_Five    =  $60 ; | XX     |
Line1_Five    =  $7E ; | XXXXXX |

Line8_Six     =  $3C ; |  XXXX  |
Line7_Six     =  $66 ; | XX  XX |
Line6_Six     =  $66 ; | XX  XX |
Line5_Six     =  $66 ; | XX  XX |
Line4_Six     =  $7C ; | XXXXX  |
Line3_Six     =  $60 ; | XX     |
Line2_Six     =  $62 ; | XX   X |
Line1_Six     =  $3C ; |  XXXX  |

Line8_Seven   =  $18 ; |   XX   |
Line7_Seven   =  $18 ; |   XX   |
Line6_Seven   =  $18 ; |   XX   |
Line5_Seven   =  $18 ; |   XX   |
Line4_Seven   =  $0C ; |    XX  |
Line3_Seven   =  $06 ; |     XX |
Line2_Seven   =  $46 ; | X   XX |
Line1_Seven   =  $7E ; | XXXXXX |

Line8_Eight   =  $3C ; |  XXXX  |
Line7_Eight   =  $66 ; | XX  XX |
Line6_Eight   =  $66 ; | XX  XX |
Line5_Eight   =  $66 ; | XX  XX |
Line4_Eight   =  $3C ; |  XXXX  |
Line3_Eight   =  $66 ; | XX  XX |
Line2_Eight   =  $66 ; | XX  XX |
Line1_Eight   =  $3C ; |  XXXX  |

Line8_Nine    =  $3C ; |  XXXX  |
Line7_Nine    =  $46 ; | X   XX |
Line6_Nine    =  $06 ; |     XX |
Line5_Nine    =  $3E ; |  XXXXX |
Line4_Nine    =  $66 ; | XX  XX |
Line3_Nine    =  $66 ; | XX  XX |
Line2_Nine    =  $66 ; | XX  XX |
Line1_Nine    =  $3C ; |  XXXX  |


Line8_Let_A    = $66 ; | XX  XX |
Line7_Let_A    = $66 ; | XX  XX |
Line6_Let_A    = $66 ; | XX  XX |
Line5_Let_A    = $7E ; | XXXXXX |
Line4_Let_A    = $66 ; | XX  XX |
Line3_Let_A    = $66 ; | XX  XX |
Line2_Let_A    = $3C ; |  XXXX  |
Line1_Let_A    = $18 ; |   XX   |

Line8_Let_B    = $7C ; | XXXXX  |
Line7_Let_B    = $66 ; | XX  XX |
Line6_Let_B    = $66 ; | XX  XX |
Line5_Let_B    = $66 ; | XX  XX |
Line4_Let_B    = $7C ; | XXXXX  |
Line3_Let_B    = $66 ; | XX  XX |
Line2_Let_B    = $66 ; | XX  XX |
Line1_Let_B    = $7C ; | XXXXX  |

Line8_Let_C    = $3C ; |  XXXX  |
Line7_Let_C    = $66 ; | XX  XX |
Line6_Let_C    = $60 ; | XX     |
Line5_Let_C    = $60 ; | XX     |
Line4_Let_C    = $60 ; | XX     |
Line3_Let_C    = $60 ; | XX     |
Line2_Let_C    = $66 ; | XX  XX |
Line1_Let_C    = $3C ; |  XXXX  |

Line8_Let_D    = $78 ; | XXXX   |
Line7_Let_D    = $6C ; | XX XX  |
Line6_Let_D    = $66 ; | XX  XX |
Line5_Let_D    = $66 ; | XX  XX |
Line4_Let_D    = $66 ; | XX  XX |
Line3_Let_D    = $66 ; | XX  XX |
Line2_Let_D    = $6C ; | XX XX  |
Line1_Let_D    = $78 ; | XXXX   |

Line8_Let_E    = $7E ; | XXXXXX |
Line7_Let_E    = $60 ; | XX     |
Line6_Let_E    = $60 ; | XX     |
Line5_Let_E    = $60 ; | XX     |
Line4_Let_E    = $7C ; | XXXXX  |
Line3_Let_E    = $60 ; | XX     |
Line2_Let_E    = $60 ; | XX     |
Line1_Let_E    = $7E ; | XXXXXX |

Line8_Let_F    = $60 ; | XX     |
Line7_Let_F    = $60 ; | XX     |
Line6_Let_F    = $60 ; | XX     |
Line5_Let_F    = $60 ; | XX     |
Line4_Let_F    = $7C ; | XXXXX  |
Line3_Let_F    = $60 ; | XX     |
Line2_Let_F    = $60 ; | XX     |
Line1_Let_F    = $7E ; | XXXXXX |

Line8_Let_G    = $3C ; |  XXXX  |
Line7_Let_G    = $66 ; | XX  XX |
Line6_Let_G    = $66 ; | XX  XX |
Line5_Let_G    = $66 ; | XX  XX |
Line4_Let_G    = $6E ; | XX XXX |
Line3_Let_G    = $60 ; | XX     |
Line2_Let_G    = $66 ; | XX  XX |
Line1_Let_G    = $3C ; |  XXXX  |

Line8_Let_H    = $66 ; | XX  XX |
Line7_Let_H    = $66 ; | XX  XX |
Line6_Let_H    = $66 ; | XX  XX |
Line5_Let_H    = $66 ; | XX  XX |
Line4_Let_H    = $7E ; | XXXXXX |
Line3_Let_H    = $66 ; | XX  XX |
Line2_Let_H    = $66 ; | XX  XX |
Line1_Let_H    = $66 ; | XX  XX |



       ORG $FF00

Zero:
    .byte $3C ; |  XXXX  | $FF00
    .byte $66 ; | XX  XX | $FF01
    .byte $66 ; | XX  XX | $FF02
    .byte $76 ; | XXX XX | $FF03
    .byte $6E ; | XX XXX | $FF04
    .byte $66 ; | XX  XX | $FF05
    .byte $66 ; | XX  XX | $FF06
    .byte $3C ; |  XXXX  | $FF07
One:
    .byte $7E ; | XXXXXX | $FF08
    .byte $18 ; |   XX   | $FF09
    .byte $18 ; |   XX   | $FF0A
    .byte $18 ; |   XX   | $FF0B
    .byte $18 ; |   XX   | $FF0C
    .byte $18 ; |   XX   | $FF0D
    .byte $38 ; |  XXX   | $FF0E
    .byte $08 ; |    X   | $FF0F
Two:
    .byte $7E ; | XXXXXX | $FF10
    .byte $60 ; | XX     | $FF11
    .byte $60 ; | XX     | $FF12
    .byte $3C ; |  XXXX  | $FF13
    .byte $06 ; |     XX | $FF14
    .byte $06 ; |     XX | $FF15
    .byte $46 ; | X   XX | $FF16
    .byte $3C ; |  XXXX  | $FF17
Three:
    .byte $3C ; |  XXXX  | $FF18
    .byte $46 ; | X   XX | $FF19
    .byte $06 ; |     XX | $FF1A
    .byte $0C ; |    XX  | $FF1B
    .byte $0C ; |    XX  | $FF1C
    .byte $06 ; |     XX | $FF1D
    .byte $46 ; | X   XX | $FF1E
    .byte $3C ; |  XXXX  | $FF1F
Four:
    .byte $0C ; |    XX  | $FF20
    .byte $0C ; |    XX  | $FF21
    .byte $0C ; |    XX  | $FF22
    .byte $7E ; | XXXXXX | $FF23
    .byte $4C ; | X  XX  | $FF24
    .byte $2C ; |  X XX  | $FF25
    .byte $1C ; |   XXX  | $FF26
    .byte $0C ; |    XX  | $FF27
Five:
    .byte $3C ; |  XXXX  | $FF28
    .byte $46 ; | X   XX | $FF29
    .byte $06 ; |     XX | $FF2A
    .byte $06 ; |     XX | $FF2B
    .byte $7C ; | XXXXX  | $FF2C
    .byte $60 ; | XX     | $FF2D
    .byte $60 ; | XX     | $FF2E
    .byte $7E ; | XXXXXX | $FF2F
Six:
    .byte $3C ; |  XXXX  | $FF30
    .byte $66 ; | XX  XX | $FF31
    .byte $66 ; | XX  XX | $FF32
    .byte $66 ; | XX  XX | $FF33
    .byte $7C ; | XXXXX  | $FF34
    .byte $60 ; | XX     | $FF35
    .byte $62 ; | XX   X | $FF36
    .byte $3C ; |  XXXX  | $FF37
Seven:
    .byte $18 ; |   XX   | $FF38
    .byte $18 ; |   XX   | $FF39
    .byte $18 ; |   XX   | $FF3A
    .byte $18 ; |   XX   | $FF3B
    .byte $0C ; |    XX  | $FF3C
    .byte $06 ; |     XX | $FF3D
    .byte $46 ; | X   XX | $FF3E
    .byte $7E ; | XXXXXX | $FF3F
Eight:
    .byte $3C ; |  XXXX  | $FF40
    .byte $66 ; | XX  XX | $FF41
    .byte $66 ; | XX  XX | $FF42
    .byte $66 ; | XX  XX | $FF43
    .byte $3C ; |  XXXX  | $FF44
    .byte $66 ; | XX  XX | $FF45
    .byte $66 ; | XX  XX | $FF46
    .byte $3C ; |  XXXX  | $FF47
Nine:
    .byte $3C ; |  XXXX  | $FF48
    .byte $46 ; | X   XX | $FF49
    .byte $06 ; |     XX | $FF4A
    .byte $3E ; |  XXXXX | $FF4B
    .byte $66 ; | XX  XX | $FF4C
    .byte $66 ; | XX  XX | $FF4D
    .byte $66 ; | XX  XX | $FF4E
    .byte $3C ; |  XXXX  | $FF4F
LetterA:
    .byte $66 ; | XX  XX | $FF50
    .byte $66 ; | XX  XX | $FF51
    .byte $66 ; | XX  XX | $FF52
    .byte $7E ; | XXXXXX | $FF53
    .byte $66 ; | XX  XX | $FF54
    .byte $66 ; | XX  XX | $FF55
    .byte $3C ; |  XXXX  | $FF56
    .byte $18 ; |   XX   | $FF57
LetterB:
    .byte $7C ; | XXXXX  | $FF58
    .byte $66 ; | XX  XX | $FF59
    .byte $66 ; | XX  XX | $FF5A
    .byte $66 ; | XX  XX | $FF5B
    .byte $7C ; | XXXXX  | $FF5C
    .byte $66 ; | XX  XX | $FF5D
    .byte $66 ; | XX  XX | $FF5E
    .byte $7C ; | XXXXX  | $FF5F
LetterC:
    .byte $3C ; |  XXXX  | $FF60
    .byte $66 ; | XX  XX | $FF61
    .byte $60 ; | XX     | $FF62
    .byte $60 ; | XX     | $FF63
    .byte $60 ; | XX     | $FF64
    .byte $60 ; | XX     | $FF65
    .byte $66 ; | XX  XX | $FF66
    .byte $3C ; |  XXXX  | $FF67
LetterD:
    .byte $78 ; | XXXX   | $FF68
    .byte $6C ; | XX XX  | $FF69
    .byte $66 ; | XX  XX | $FF6A
    .byte $66 ; | XX  XX | $FF6B
    .byte $66 ; | XX  XX | $FF6C
    .byte $66 ; | XX  XX | $FF6D
    .byte $6C ; | XX XX  | $FF6E
    .byte $78 ; | XXXX   | $FF6F
LetterE:
    .byte $7E ; | XXXXXX | $FF70
    .byte $60 ; | XX     | $FF71
    .byte $60 ; | XX     | $FF72
    .byte $60 ; | XX     | $FF73
    .byte $7C ; | XXXXX  | $FF74
    .byte $60 ; | XX     | $FF75
    .byte $60 ; | XX     | $FF76
    .byte $7E ; | XXXXXX | $FF77
LetterF:
    .byte $60 ; | XX     | $FF78
    .byte $60 ; | XX     | $FF79
    .byte $60 ; | XX     | $FF7A
    .byte $60 ; | XX     | $FF7B
    .byte $7C ; | XXXXX  | $FF7C
    .byte $60 ; | XX     | $FF7D
    .byte $60 ; | XX     | $FF7E
    .byte $7E ; | XXXXXX | $FF7F
LetterG:
    .byte $3C ; |  XXXX  | $FF80
    .byte $66 ; | XX  XX | $FF81
    .byte $66 ; | XX  XX | $FF82
    .byte $66 ; | XX  XX | $FF83
    .byte $6E ; | XX XXX | $FF84
    .byte $60 ; | XX     | $FF85
    .byte $66 ; | XX  XX | $FF86
    .byte $3C ; |  XXXX  | $FF87
LetterH:
    .byte $66 ; | XX  XX | $FF88
    .byte $66 ; | XX  XX | $FF89
    .byte $66 ; | XX  XX | $FF8A
    .byte $66 ; | XX  XX | $FF8B
    .byte $7E ; | XXXXXX | $FF8C
    .byte $66 ; | XX  XX | $FF8D
    .byte $66 ; | XX  XX | $FF8E
    .byte $66 ; | XX  XX | $FF8F


StandardNumTab:
    .byte <Zero
    .byte <One
    .byte <Two
    .byte <Three
    .byte <Four
    .byte <Five
    .byte <Six
    .byte <Seven
    .byte <Eight
    .byte <Nine
    .byte <LetterA
    .byte <LetterB
    .byte <LetterC
    .byte <LetterD
    .byte <LetterE
    .byte <LetterF
    .byte <LetterG
    .byte <LetterH

FasterNumTab:
    .byte <LineEightGfx_A
    .byte <LineEightGfx_A+1
    .byte <LineEightGfx_A+2
    .byte <LineEightGfx_A+3
    .byte <LineEightGfx_A+4
    .byte <LineEightGfx_A+5
    .byte <LineEightGfx_A+6
    .byte <LineEightGfx_A+7
    .byte <LineEightGfx_A+8

    .byte <LineEightGfx_B
    .byte <LineEightGfx_B+1
    .byte <LineEightGfx_B+2
    .byte <LineEightGfx_B+3
    .byte <LineEightGfx_B+4
    .byte <LineEightGfx_B+5
    .byte <LineEightGfx_B+6
    .byte <LineEightGfx_B+7
    .byte <LineEightGfx_B+8

       ORG $FFFC

    .word START
    .word START